instrumenttools.Harp
====================

.. abjad-lineage:: abjad.tools.instrumenttools.Harp.Harp.Harp

.. autoclass:: abjad.tools.instrumenttools.Harp.Harp.Harp
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.Harp.Harp.Harp.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harp.Harp.Harp.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harp.Harp.Harp.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harp.Harp.Harp.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harp.Harp.Harp.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harp.Harp.Harp.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harp.Harp.Harp.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harp.Harp.Harp.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harp.Harp.Harp.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harp.Harp.Harp.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harp.Harp.Harp.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harp.Harp.Harp.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.Harp.Harp.Harp.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harp.Harp.Harp.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harp.Harp.Harp.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harp.Harp.Harp.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harp.Harp.Harp.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harp.Harp.Harp.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harp.Harp.Harp.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harp.Harp.Harp.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.Harp.Harp.Harp.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Harp.Harp.Harp.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Harp.Harp.Harp.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Harp.Harp.Harp.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.Harp.Harp.Harp.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Harp.Harp.Harp.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Harp.Harp.Harp.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Harp.Harp.Harp.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Harp.Harp.Harp.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Harp.Harp.Harp.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Harp.Harp.Harp.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Harp.Harp.Harp.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Harp.Harp.Harp.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Harp.Harp.Harp.__repr__
   :noindex:
